package com.sample;

import static org.junit.Assert.assertEquals;

import java.io.File;
import java.io.FileWriter;

import org.drools.KnowledgeBase;
import org.drools.agent.KnowledgeAgent;
import org.drools.agent.KnowledgeAgentFactory;
import org.drools.io.ResourceFactory;
import org.junit.Test;

/**
 * 
 * Class to reproduce that it is not possible to load CSV decision table
 * via knowledge agent changeset.
 * 
 * @author jsvitak
 * @version BRMS 5.2.0 ER3
 *
 */
public class LoadCSV {

    @Test
    public void testSimpleCSVLoad() throws Exception {

        File csvFile = new File("test-resources", "sample.csv");
        final String CSV_CHANGESET = 
            "<change-set xmlns=\"http://drools.org/drools-5.0/change-set\"\n" +
            "            xmlns:xs=\"http://www.w3.org/2001/XMLSchema-instance\"\n" +
            "            xs:schemaLocation=\"http://drools.org/drools-5.0/change-set http://anonsvn.jboss.org/repos/labs/labs/jbossrules/trunk/drools-api/src/main/resources/change-set-1.0.0.xsd\">\n" +
            "  <add>\n" +
            "    <resource source=\"file:" + csvFile.getAbsolutePath() + "\" type=\"DTABLE\">\n" +
            
            // if the worksheet-name is omitted, it shows error, but it should not, because in xsd it is specified as optional
            "      <decisiontable-conf input-type=\"CSV\" worksheet-name=\"Tables\"/>\n" +
            //"      <decisiontable-conf input-type=\"CSV\" />\n" +
            
            "    </resource>\n" +
            "  </add>\n" +
            "</change-set>\n";
        
        File csvChangeset = new File("csvChangeset.xml");
        csvChangeset.deleteOnExit();
        writeToFile(csvChangeset, CSV_CHANGESET);

        //System.out.println(CSV_CHANGESET);
        
        KnowledgeAgent kagent = KnowledgeAgentFactory.newKnowledgeAgent("csv agent");
        kagent.applyChangeSet(ResourceFactory.newFileResource(csvChangeset));
        KnowledgeBase kbase = kagent.getKnowledgeBase();
        
        assertEquals(kbase.getKnowledgePackages().size(), 1);
        assertEquals(kbase.getKnowledgePackages().iterator().next().getRules().size(), 3);
        
        kagent.dispose();
    }
    
    private void writeToFile(File file, String content) throws Exception {
        FileWriter fw = null;

        try {
            fw = new FileWriter(file);
            fw.write(content);
        } finally {
            if (fw != null) fw.close();
        }
    }

    public static class Person {
        private int id;

        public void setId(int id) {
            this.id = id;
        }

        public int getId() {
            return id;
        }
        
    }

}
